# dashport

Dashport - An easy and safe way to use curses

## Installation

You can install from source code by cloning down this repo and running:

```
pip install .
```

Alternatively, use this to install from PyPI:

```
pip install dashport
```

This is still a new repo, so waiting to see if it's worth it to publish to PyPI.
